Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/dtexp/__init__.py | (no class) | 4 | 0 | 0 | 100%
src/dtexp/addition.py | (no class) | 5 | 0 | 0 | 100%
src/dtexp/conditions.py | (no class) | 72 | 0 | 0 | 100%
src/dtexp/exceptions.py | DtexpParsingError | 0 | 0 | 0 | 100%
src/dtexp/exceptions.py | DtexpMaxIterationError | 0 | 0 | 0 | 100%
src/dtexp/exceptions.py | (no class) | 2 | 0 | 0 | 100%
src/dtexp/parse_expression.py | (no class) | 112 | 0 | 0 | 100%
src/dtexp/parse_timestamp.py | (no class) | 39 | 0 | 0 | 100%
Total |  | 234 | 0 | 0 | 100%

No items found using the specified filter.